"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const leaflet_1 = __importDefault(require("leaflet"));
const React = __importStar(require("react"));
const leafletCss_1 = __importDefault(require("./leafletCss"));
const MIMETYPE = "application/geo+json";
leaflet_1.default.Icon.Default.imagePath = "../node_modules/leaflet/dist/images/";
function getLuma(el) {
    // https://en.wikipedia.org/wiki/Luma_(video)
    const style = window.getComputedStyle(el);
    const [r, g, b] = style
        .backgroundColor.replace(/^(rgb|rgba)\(/, "")
        .replace(/\)$/, "")
        .replace(/\s/g, "")
        .split(",");
    // Digital ITU BT.601
    // http://www.itu.int/rec/R-REC-BT.601
    const y = 0.299 * Number(r) + 0.587 * Number(g) + 0.114 * Number(b);
    return y / 255;
}
exports.getLuma = getLuma;
function getTheme(theme = "light", el) {
    switch (theme) {
        case "light":
        case "dark":
            return theme;
        default:
            if (getLuma(el) < 0.5) {
                return "dark";
            }
            return "light";
    }
}
exports.getTheme = getTheme;
class GeoJSONTransform extends React.Component {
    constructor() {
        super(...arguments);
        this.getTileLayer = () => {
            if (!this.el) {
                return;
            }
            const theme = getTheme(this.props.theme, this.el);
            // const urlTemplate = (this.props.metadata && this.props.metadata.url_template) ||
            //   'https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png';
            const urlTemplate = (this.props.metadata && this.props.metadata.url_template) ||
                "https://api.tiles.mapbox.com/v4/{id}/{z}/{x}/{y}.png?access_token=pk.eyJ1IjoibWlja3QiLCJhIjoiLXJIRS1NbyJ9.EfVT76g4A5dyuApW_zuIFQ";
            // const layerOptions = (this.props.metadata && this.props.metadata.layer_options) || {
            //   attribution: 'Map data (c) <a href="https://openstreetmap.org">OpenStreetMap</a> contributors',
            //   minZoom: 0,
            //   maxZoom: 18
            // };
            const layerOptions = (this.props.metadata &&
                this.props.metadata.layer_options) || {
                attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a>',
                id: `mapbox.${theme}`
            };
            return { urlTemplate, layerOptions };
        };
    }
    componentDidMount() {
        this.map = leaflet_1.default.map(this.el);
        this.map.scrollWheelZoom.disable();
        const tileLayerOptions = this.getTileLayer();
        this.tileLayer = leaflet_1.default.tileLayer(tileLayerOptions.urlTemplate, tileLayerOptions.layerOptions).addTo(this.map);
        const geoJSON = this.props.data;
        this.geoJSONLayer = leaflet_1.default.geoJSON(geoJSON).addTo(this.map);
        this.map.fitBounds(this.geoJSONLayer.getBounds());
    }
    shouldComponentUpdate(nextProps) {
        if (nextProps.theme !== this.props.theme ||
            this.props.data !== nextProps.data) {
            return true;
        }
        return false;
    }
    componentDidUpdate(prevProps) {
        if (prevProps.theme !== this.props.theme) {
            this.map.removeLayer(this.tileLayer);
            const tileLayerOptions = this.getTileLayer();
            this.tileLayer = leaflet_1.default.tileLayer(tileLayerOptions.urlTemplate, tileLayerOptions.layerOptions).addTo(this.map);
        }
        if (prevProps.data !== this.props.data) {
            const geoJSON = this.props.data;
            this.map.removeLayer(this.geoJSONLayer);
            this.geoJSONLayer = leaflet_1.default.geoJSON(geoJSON).addTo(this.map);
            this.map.fitBounds(this.geoJSONLayer.getBounds());
        }
    }
    render() {
        return (React.createElement(React.Fragment, null,
            React.createElement("div", { ref: el => {
                    this.el = el;
                }, style: { height: 600, width: "100%" } }),
            React.createElement(leafletCss_1.default, null)));
    }
}
exports.GeoJSONTransform = GeoJSONTransform;
GeoJSONTransform.defaultProps = {
    theme: "light",
    mediaType: MIMETYPE
};
GeoJSONTransform.MIMETYPE = MIMETYPE;
exports.default = GeoJSONTransform;
